import os
import buzhug
from datetime import datetime
db = buzhug.Base('entries')

try:
    db.open()
except IOError:
    db.create(('parent',int),('thread',int),('author',str),
        ('title',str),('content',str),('date',datetime),
        ('lastDate',datetime),('numChildren',int))

class Message:

    def __init__(self,author,title,content,parent=-1,thread=-1,date=None, lastDate=None):
        """parent = messageId of the message to which self is an answer 
        (empty if new thread)"""
        self.parent=parent
        self.thread=thread
        self.author=author
        self.title=title
        self.content=content
        if date is None:
            self.date=time.localtime(time.time())
        else:
            self.date=date
        if lastDate is None:
            self.lastDate=self.date
        else:
            self.lastDate=lastDate
        self.numChildren=0

